@@ -3,6 +3,11 @@ import requests
 
 class LicenseMixin:
 
+    def check_license(self):
+        print("(2/5) license")
+        results = [self.has_license()]
+        return True in results
+
     def has_license(self):
         url = "https://api.github.com/repos/{0}/{1}/license".format(self.owner, self.repo)
         try:
@@ -12,7 +17,5 @@ class LicenseMixin:
         except requests.HTTPError:
             self.print_state(check_name="has_license", state=False)
             return False
-        except Exception as err:
-            print(f"Other error occurred: {err}")
         self.print_state(check_name="has_license", state=True)
         return True
