@@ -3,6 +3,11 @@ import requests
 
 class RepositoryMixin:
 
+    def check_repository(self):
+        print("(1/5) repository")
+        results = [self.has_open_repository()]
+        return True in results
+
     def has_open_repository(self):
         url = "https://api.github.com/repos/{0}/{1}".format(self.owner, self.repo)
 
